@@ -1,7 +1,9 @@
 """Adapters for registering models with django-watson."""
 
-import sys
-from itertools import chain
+from __future__ import unicode_literals
+
+import sys, json
+from itertools import chain, islice
 from threading import local
 from functools import wraps
 from weakref import WeakValueDictionary
@@ -14,9 +16,9 @@ from django.db import models
 from django.db.models import Q
 from django.db.models.query import QuerySet
 from django.db.models.signals import post_save, pre_delete
+from django.utils.encoding import force_text
 from django.utils.html import strip_tags
 from django.utils.importlib import import_module
-from django.utils import simplejson as json
 
 from watson.models import SearchEntry, has_int_pk
 
@@ -65,11 +67,11 @@ class SearchAdapter(object):
         # Look up recursive fields.
         if len(name_parts) == 2:
             if isinstance(value, (QuerySet, models.Manager)):
-                return u" ".join(unicode(self._resolve_field(obj, name_parts[1])) for obj in value.all())
+                return " ".join(force_text(self._resolve_field(obj, name_parts[1])) for obj in value.all())
             return self._resolve_field(value, name_parts[1])
         # Resolve querysets.
         if isinstance(value, (QuerySet, models.Manager)):
-            value = u" ".join(unicode(related) for related in value.all())
+            value = " ".join(force_text(related) for related in value.all())
         # Resolution complete!
         return value
     
@@ -85,9 +87,9 @@ class SearchAdapter(object):
         
         You can access the title of the search entry as `entry.title` in your search results.
         
-        The default implementation returns `unicode(obj)`.
+        The default implementation returns `force_text(obj)`.
         """
-        return unicode(obj)
+        return force_text(obj)
         
     def get_description(self, obj):
         """
@@ -97,9 +99,9 @@ class SearchAdapter(object):
         this should contains a short description of the search entry, it's excellent for providing a summary
         in your search results.
         
-        The default implementation returns `u""`.
+        The default implementation returns `""`.
         """
-        return u""
+        return ""
         
     def get_content(self, obj):
         """
@@ -115,8 +117,8 @@ class SearchAdapter(object):
         # Exclude named fields.
         field_names = (field_name for field_name in field_names if field_name not in self.exclude)
         # Create the text.
-        return self.prepare_content(u" ".join(
-            unicode(self._resolve_field(obj, field_name))
+        return self.prepare_content(" ".join(
+            force_text(self._resolve_field(obj, field_name))
             for field_name in field_names
         ))
     
@@ -124,7 +126,7 @@ class SearchAdapter(object):
         """Return the URL of the given obj."""
         if hasattr(obj, "get_absolute_url"):
             return obj.get_absolute_url()
-        return u""
+        return ""
     
     def get_meta(self, obj):
         """Returns a dictionary of meta information about the given obj."""
@@ -157,12 +159,16 @@ class SearchContextError(Exception):
     """Something went wrong with the search context management."""
 
 
-def _bulk_save_search_entries(search_entries):
+def _bulk_save_search_entries(search_entries, batch_size=100):
     """Creates the given search entry data in the most efficient way possible."""
     if search_entries:
         if hasattr(SearchEntry.objects, "bulk_create"):
-            search_entries = list(search_entries)
-            SearchEntry.objects.bulk_create(search_entries)
+            search_entries = iter(search_entries)
+            while True:
+                search_entry_batch = list(islice(search_entries, 0, batch_size))
+                if not search_entry_batch:
+                    break
+                SearchEntry.objects.bulk_create(search_entry_batch)
         else:
             for search_entry in search_entries:
                 search_entry.save()
@@ -330,7 +336,8 @@ class SearchEngine(object):
             ))
         # Perform any customization.
         if field_overrides:
-            adapter_cls = type("Custom" + adapter_cls.__name__, (adapter_cls,), field_overrides)
+            # Conversion to str is needed because Python 2 doesn't accept unicode for class name
+            adapter_cls = type(str("Custom") + adapter_cls.__name__, (adapter_cls,), field_overrides)
         # Perform the registration.
         adapter_obj = adapter_cls(model)
         self._registered_models[model] = adapter_obj
@@ -361,7 +368,7 @@ class SearchEngine(object):
         
     def get_registered_models(self):
         """Returns a sequence of models that have been registered with this search engine."""
-        return self._registered_models.keys()
+        return list(self._registered_models.keys())
     
     def get_adapter(self, model):
         """Returns the adapter associated with the given model."""
@@ -375,7 +382,7 @@ class SearchEngine(object):
         """Returns a queryset of entries associate with the given obj."""
         model = obj.__class__
         content_type = ContentType.objects.get_for_model(model)
-        object_id = unicode(obj.pk)
+        object_id = force_text(obj.pk)
         # Get the basic list of search entries.
         search_entries = SearchEntry.objects.filter(
             content_type = content_type,
@@ -400,7 +407,7 @@ class SearchEngine(object):
         model = obj.__class__
         adapter = self.get_adapter(model)
         content_type = ContentType.objects.get_for_model(model)
-        object_id = unicode(obj.pk)
+        object_id = force_text(obj.pk)
         # Create the search entry data.
         search_entry_data = {
             "engine_slug": self._engine_slug,
@@ -569,4 +576,4 @@ def get_backend():
     # Initialize the backend.
     backend = backend_cls()
     _backend_cache = backend
-    return backend
\ No newline at end of file
+    return backend
