@@ -9,7 +9,10 @@ these tests have been amended to 'fooo' and 'baar'. Ho hum.
 from __future__ import unicode_literals
 
 import os, json
-from unittest import skipUnless
+try:
+    from unittest import skipUnless
+except:
+    from django.utils.unittest import skipUnless
 
 from django.db import models
 from django.test import TestCase
@@ -180,17 +183,37 @@ class InternalsTest(SearchTestBase):
 
     def testSearchEntriesCreated(self):
         self.assertEqual(SearchEntry.objects.filter(engine_slug="default").count(), 4)
-        
+
+    def testBuildWatsonForModelCommand(self):
+        # Hack a change into the model using a bulk update, which doesn't send signals.
+        WatsonTestModel1.objects.filter(id=self.test11.id).update(title="fooo1_selective")
+        WatsonTestModel2.objects.filter(id=self.test21.id).update(title="fooo2_selective")
+        # Test that no update has happened.
+        self.assertEqual(watson.search("fooo1_selective").count(), 0)
+        self.assertEqual(watson.search("fooo2_selective").count(), 0)
+        # Run the rebuild command.
+        call_command("buildwatson", "WatsonTestModel1", verbosity=0)
+        # Test that the update is now applied to selected model.
+        self.assertEqual(watson.search("fooo1_selective").count(), 1)
+        self.assertEqual(watson.search("fooo2_selective").count(), 0)
+        call_command("buildwatson", "WatsonTestModel1", "WatsonTestModel2", verbosity=0)
+        # Test that the update is now applied to multiple selected models.
+        self.assertEqual(watson.search("fooo1_selective").count(), 1)
+        self.assertEqual(watson.search("fooo2_selective").count(), 1)
+
     def testBuildWatsonCommand(self):
         # Hack a change into the model using a bulk update, which doesn't send signals.
-        WatsonTestModel1.objects.filter(id=self.test11.id).update(title="fooo")
+        WatsonTestModel1.objects.filter(id=self.test11.id).update(title="fooo1")
+        WatsonTestModel2.objects.filter(id=self.test21.id).update(title="fooo2")
         # Test that no update has happened.
-        self.assertEqual(watson.search("fooo").count(), 0)
+        self.assertEqual(watson.search("fooo1").count(), 0)
+        self.assertEqual(watson.search("fooo2").count(), 0)
         # Run the rebuild command.
         call_command("buildwatson", verbosity=0)
-        # Test that the update is now applies.
-        self.assertEqual(watson.search("fooo").count(), 1)
-        
+        # Test that the update is now applied.
+        self.assertEqual(watson.search("fooo1").count(), 1)
+        self.assertEqual(watson.search("fooo2").count(), 1)
+
     def testUpdateSearchIndex(self):
         # Update a model and make sure that the search results match.
         self.test11.title = "fooo"
@@ -283,6 +306,14 @@ class SearchTest(SearchTestBase):
         self.assertEqual(watson.search("FOOO").count(), 0)
         self.assertEqual(watson.search("FOOO INSTANCE11").count(), 0)
         self.assertEqual(watson.search("MODEL2 INSTANCE11").count(), 0)
+
+    def testSearchWithApostrophe(self):
+        WatsonTestModel1.objects.create(
+            title = "title model1 instance12",
+            content = "content model1 instance13 d'Argent",
+            description = "description model1 instance13",
+        )
+        self.assertEqual(watson.search("d'Argent").count(), 1)
         
     @skipUnless(get_backend().supports_prefix_matching, "Search backend does not support prefix matching.")
     def testMultiTablePrefixSearch(self):
